SELECT 1/asyncmy - Criterion.rs

## SELECT 1/asyncmy

#### Additional Statistics:

| Lower bound | Estimate | Upper bound
--- | --- | --- | ---
R² | 0.0081146 | 0.0084081 | 0.0080797
Mean | 18.210 ms | 18.434 ms | 18.671 ms
Std. Dev. | 988.85 µs | 1.1763 ms | 1.3393 ms
Median | 17.735 ms | 18.057 ms | 18.439 ms
MAD | 613.55 µs | 1.0005 ms | 1.4115 ms

#### Additional Plots:

- Typical
- Mean
- Std. Dev.
- Median
- MAD

#### Understanding this report:

The plot on the left displays the average time per iteration for this benchmark. The shaded region shows the estimated probability of an iteration taking a certain amount of time, while the line shows the mean. Click on the plot for a larger view showing the outliers.

The plot on the right shows the average time per iteration for the samples. Each point represents one sample.

See the documentation for more details on the additional statistics.